@@ -1,4 +1,4 @@
-###--- >>> `write' <<<----- Write data to a file
+###--- >>> `write' <<<----- Write Data to a File
 
 	## alias	 help(write)
 
@@ -14,6 +14,7 @@ write(t(x))
 # the file data now contains the data in x,
 # two rows, five cols but the first row is 1 2 3 4 5
 write(x)
+unlink("data") # tidy up
 
 ## Keywords: 'file'.
 
